;; Generated package description from aumix-mode.el  -*- no-byte-compile: t -*-
(define-package "aumix-mode" "7.0.20210420.181214" "run the aumix program in a buffer" 'nil :keywords '("multimedia" "mixer" "aumix") :authors '(("Kevin Ryde" . "user42_kevin@yahoo.com.au")) :maintainer '("Kevin Ryde" . "user42_kevin@yahoo.com.au") :url "http://user42.tuxfamily.org/aumix-mode/index.html")
